#region Copyright Syncfusion Inc. 2001 - 2014
//
//  Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Any infringement will be prosecuted under
//  applicable laws. 
//
#endregion

using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using Syncfusion.XlsIO;

namespace WebSampleBrowser.XlsIO
{
    public partial class DataValidation : System.Web.UI.Page
    {
        # region Page Load
        /// <summary>
        /// Handles the page load
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_Load(object sender, EventArgs e)
        {

        }
        # endregion

        # region Events
        /// <summary>
        /// Creates spreadsheet
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Button1_Click(object sender, EventArgs e)
        {
            //New instance of XlsIO is created.[Equivalent to launching MS Excel with no workbooks open].
            //The instantiation process consists of two steps.

            //Step 1 : Instantiate the spreadsheet creation engine.
            ExcelEngine excelEngine = new ExcelEngine();
            //Step 2 : Instantiate the excel application object.
            IApplication application = excelEngine.Excel;

            //Default version is set as Excel 2007
            if (this.rdButtonXlsx.Checked)
                application.DefaultVersion = ExcelVersion.Excel2007;
            else if (this.rdButtonXls.Checked)
                application.DefaultVersion = ExcelVersion.Excel97to2003;
            else if (this.rdButtonXlsx2010.Checked)
                application.DefaultVersion = ExcelVersion.Excel2010;
            else if (this.rdButtonXlsx2013.Checked)
                application.DefaultVersion = ExcelVersion.Excel2013;

            //A new workbook is created.[Equivalent to creating a new workbook in MS Excel]
            //The new workbook will have 3 worksheets
            IWorkbook workbook = application.Workbooks.Create(3);
            //The first worksheet object in the worksheets collection is accessed.
            IWorksheet sheet = workbook.Worksheets[0];

            //Data validation to list the values in the first cell
            IDataValidation validation = sheet.Range["C7"].DataValidation;
            sheet.Range["B7"].Text = "Select an item from the validation list";
            validation.ListOfValues = new string[] { "PDF", "XlsIO", "DocIO" };
            validation.PromptBoxText = "Data Validation list";
            validation.IsPromptBoxVisible = true;
            validation.ShowPromptBox = true;

            sheet.Range["C7"].CellStyle.Borders.LineStyle = ExcelLineStyle.Medium;
            sheet.Range["C7"].CellStyle.Borders[ExcelBordersIndex.DiagonalDown].ShowDiagonalLine = false;
            sheet.Range["C7"].CellStyle.Borders[ExcelBordersIndex.DiagonalUp].ShowDiagonalLine = false;

            // Data Validation for Numbers
            IDataValidation validation1 = sheet.Range["C9"].DataValidation;
            sheet.Range["B9"].Text = "Enter a Number to validate";
            validation1.AllowType = ExcelDataType.Integer;
            validation1.CompareOperator = ExcelDataValidationComparisonOperator.Between;
            validation1.FirstFormula = "0";
            validation1.SecondFormula = "10";
            validation1.ShowErrorBox = true;
            validation1.ErrorBoxText = "Enter Value between 0 to 10";
            validation1.ErrorBoxTitle = "ERROR";
            validation1.PromptBoxText = "Data Validation using Condition for Numbers";
            validation1.ShowPromptBox = true;
            sheet.Range["C9"].CellStyle.Borders.LineStyle = ExcelLineStyle.Medium;
            sheet.Range["C9"].CellStyle.Borders[ExcelBordersIndex.DiagonalDown].ShowDiagonalLine = false;
            sheet.Range["C9"].CellStyle.Borders[ExcelBordersIndex.DiagonalUp].ShowDiagonalLine = false;

            // Data Validation for Date
            IDataValidation validation2 = sheet.Range["C11"].DataValidation;
            sheet.Range["B11"].Text = "Enter the Date to validate";
            validation2.AllowType = ExcelDataType.Date;
            validation2.CompareOperator = ExcelDataValidationComparisonOperator.Between;
            validation2.FirstDateTime = new DateTime(2003, 5, 10);
            validation2.SecondDateTime = new DateTime(2004, 5, 10);
            validation2.ShowErrorBox = true;
            validation2.ErrorBoxText = "Enter Value between 5/10/2003 to 5/10/2004";
            validation2.ErrorBoxTitle = "ERROR";
            validation2.PromptBoxText = "Data Validation using Condition for Date";
            validation2.ShowPromptBox = true;
            sheet.Range["C11"].CellStyle.Borders.LineStyle = ExcelLineStyle.Medium;
            sheet.Range["C11"].CellStyle.Borders[ExcelBordersIndex.DiagonalDown].ShowDiagonalLine = false;
            sheet.Range["C11"].CellStyle.Borders[ExcelBordersIndex.DiagonalUp].ShowDiagonalLine = false;

            // Data Validation for TextLength
            IDataValidation validation3 = sheet.Range["C13"].DataValidation;
            sheet.Range["B13"].Text = "Enter the Text to validate";
            validation3.AllowType = ExcelDataType.TextLength;
            validation3.CompareOperator = ExcelDataValidationComparisonOperator.Between;
            validation3.FirstFormula = "1";
            validation3.SecondFormula = "6";
            validation3.ShowErrorBox = true;
            validation3.ErrorBoxText = "Retype text length to 6 character";
            validation3.ErrorBoxTitle = "ERROR";
            validation3.PromptBoxText = "Data Validation using Condition for TextLength";
            validation3.ShowPromptBox = true;
            sheet.Range["C13"].CellStyle.Borders.LineStyle = ExcelLineStyle.Medium;
            sheet.Range["C13"].CellStyle.Borders[ExcelBordersIndex.DiagonalDown].ShowDiagonalLine = false;
            sheet.Range["C13"].CellStyle.Borders[ExcelBordersIndex.DiagonalUp].ShowDiagonalLine = false;

            // Data Validation for Time
            IDataValidation validation4 = sheet.Range["C15"].DataValidation;
            sheet.Range["B15"].Text = "Enter the Time to validate";
            validation4.AllowType = ExcelDataType.Time;
            validation4.CompareOperator = ExcelDataValidationComparisonOperator.Between;
            validation4.FirstFormula = "10";
            validation4.SecondFormula = "12";
            validation4.ShowErrorBox = true;
            validation4.ErrorBoxText = "Enter the Correct time between 10 to 12 ";
            validation4.ErrorBoxTitle = "ERROR";
            validation4.PromptBoxText = "Data Validation using Condition for Time";
            validation4.ShowPromptBox = true;
            sheet.Range["C15"].CellStyle.Borders.LineStyle = ExcelLineStyle.Medium;
            sheet.Range["C15"].CellStyle.Borders[ExcelBordersIndex.DiagonalDown].ShowDiagonalLine = false;
            sheet.Range["C15"].CellStyle.Borders[ExcelBordersIndex.DiagonalUp].ShowDiagonalLine = false;
            sheet.Range["B2:C2"].Merge();
            sheet.Range["B2"].Text = "Simple Data validation";
            sheet.Range["B5"].Text = "Validation criteria";
            sheet.Range["C5"].Text = "Validation";
            sheet.Range["B5"].CellStyle.Font.Bold = true;
            sheet.Range["C5"].CellStyle.Font.Bold = true;
            sheet.Range["B2"].CellStyle.Font.Bold = true;
            sheet.Range["B2"].CellStyle.Font.Size = 16;
            sheet.Range["B2"].CellStyle.HorizontalAlignment = ExcelHAlign.HAlignCenter;
            sheet.UsedRange.AutofitColumns();
            sheet.UsedRange.AutofitRows();
            //Saving the workbook to disk.

            if (this.rdButtonXlsx.Checked)
                workbook.SaveAs("Sample.xlsx", Response, ExcelDownloadType.PromptDialog, ExcelHttpContentType.Excel2007);
            else if (this.rdButtonXls.Checked)
                workbook.SaveAs("Sample.xls", ExcelSaveType.SaveAsXLS, Response, ExcelDownloadType.PromptDialog);
            else if (this.rdButtonXlsx2010.Checked)
                workbook.SaveAs("Sample.xlsx", Response, ExcelDownloadType.PromptDialog, ExcelHttpContentType.Excel2010);
            else if (this.rdButtonXlsx2013.Checked)
                workbook.SaveAs("Sample.xlsx", Response, ExcelDownloadType.PromptDialog, ExcelHttpContentType.Excel2013);

            workbook.Close();
            excelEngine.Dispose();
        }
        # endregion
    }
}