#region Copyright Syncfusion Inc. 2001 - 2014
// Copyright Syncfusion Inc. 2001 - 2014. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Syncfusion.XlsIO;
using System.Drawing;

namespace WebSampleBrowser.XlsIO
{
    public partial class StylesAndFormatting : System.Web.UI.Page
    {
        # region Page Load
        /// <summary>
        /// Handles the page load
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_Load(object sender, EventArgs e)
        {

        }
        # endregion

        # region Events
        /// <summary>
        /// Creates spreadsheet in Excel 2007 format
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Button1_Click(object sender, EventArgs e)
        {
            //New instance of XlsIO is created.[Equivalent to launching MS Excel with no workbooks open].
            //The instantiation process consists of two steps.

            //Step 1 : Instantiate the spreadsheet creation engine.
            ExcelEngine excelEngine = new ExcelEngine();
            //Step 2 : Instantiate the excel application object.
            IApplication application = excelEngine.Excel;

            if (this.rdBtn2007.Checked)
                application.DefaultVersion = ExcelVersion.Excel2007;
            else if (this.rdBtn2010.Checked)
                application.DefaultVersion = ExcelVersion.Excel2010;
            else if (this.rdBtn2013.Checked)
                application.DefaultVersion = ExcelVersion.Excel2013;

            //A new workbook is created.[Equivalent to creating a new workbook in MS Excel]
            //The new workbook will have 12 worksheets
            IWorkbook workbook = application.Workbooks.Create(12);
            IWorkbook tempWorkbook = application.Workbooks.Open(ResolveApplicationDataPath("CalendarTemplate.xlsx"));
            workbook.Worksheets.AddCopyAfter(tempWorkbook.Worksheets[0], workbook.Worksheets[11]);

            //The first worksheet object in the worksheets collection is accessed.
            IWorksheet sheet;

            # region Calendar

            # region Draw Calendar
            String[] monthArray = new String[] { "January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December" };
            String[] dateArray = new String[] { "Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday" };
            Color[] colorArray = new Color[] { Color.FromArgb(149, 55, 53), Color.FromArgb(146, 208, 80), Color.FromArgb(0, 32, 96), Color.FromArgb(0, 176, 80), Color.FromArgb(255, 255, 0), Color.FromArgb(128, 128, 128), Color.FromArgb(255, 0, 0), Color.FromArgb(96, 73, 123), Color.FromArgb(169, 161, 117), Color.FromArgb(0, 176, 240), Color.FromArgb(192, 0, 0), Color.FromArgb(63, 49, 81), Color.FromArgb(192, 0, 0) };

            int cMonth = DateTime.Today.Month - 1;

            for (int monIndex = 1; monIndex < 13; monIndex++)
            {
                sheet = workbook.Worksheets[monIndex - 1];
                sheet.Name = monthArray[monIndex - 1];

                sheet.Range["B3:H3"].Merge();
                sheet.Range["B4:H4"].Merge();
                sheet.IsGridLinesVisible = false;

                //Write the month as the heading
                sheet.Range["B3"].Text = monthArray[monIndex - 1];

                //Apply styles for the month title
                sheet.Range["B3:H3"].HorizontalAlignment = ExcelHAlign.HAlignCenter;
                sheet.Range["B3:H3"].VerticalAlignment = ExcelVAlign.VAlignCenter;
                sheet.Range["B3:H3"].BorderAround(ExcelLineStyle.Thin, Color.Brown);
                sheet.Range["B3:H3"].RowHeight = 30;

                IStyle style = sheet.Range["B3"].CellStyle;
                style.HorizontalAlignment = ExcelHAlign.HAlignCenter;
                style.Interior.FillPattern = ExcelPattern.Gradient;
                style.Interior.Gradient.TwoColorGradient(ExcelGradientStyle.Diagonl_Up, ExcelGradientVariants.ShadingVariants_3);
                style.Interior.Gradient.ForeColorIndex = ExcelKnownColors.White;
                style.Interior.Gradient.BackColor = colorArray[monIndex - 1];
                IFont font = style.Font;
                font.FontName = "Segoe UI";
                font.Size = 22;
                font.Italic = true;

                //Write the weekdays
                for (int i = 2, j = 0; i < 9; i++, j++)
                {
                    sheet.SetValue(5, i, dateArray[j]);
                    sheet.Range[5, i].HorizontalAlignment = ExcelHAlign.HAlignCenter;
                }

                //Get the number of days in the month
                int days = DateTime.DaysInMonth(DateTime.Today.Year, monIndex);

                //Write the calendar
                DateTime firstDay = new DateTime(DateTime.Today.Year, monIndex, 1);
                IRange range = sheet.FindFirst(firstDay.Date.DayOfWeek.ToString(), ExcelFindType.Text);

                int row = range.End.Row + 1;
                int column = range.End.Column;
                int date = 1;

                while (date < days + 1)
                {
                    for (; column < 9; column++)
                    {
                        sheet.Range[row, column].Number = date;
                        date++;
                        if (date == days + 1)
                            break;
                    }
                    column = 2;
                    row++;
                }

                //Format Sunday
                sheet.Range["B5:B11"].BuiltInStyle = BuiltInStyles.WarningText;
                sheet.Range["B5"].CellStyle.HorizontalAlignment = ExcelHAlign.HAlignCenter;

                //Format day title
                sheet.Range["B5:H5"].BuiltInStyle = BuiltInStyles.Heading4;
                sheet.Range["B5:H5"].CellStyle.Font.Size = 10;

                //Border around the entire calendar
                sheet.UsedRange.BorderAround(ExcelLineStyle.Double, Color.Black);
                sheet.UsedRange.BorderInside(ExcelLineStyle.Hair, Color.Black);

                sheet.Range["B3"].RowHeight = 35;
                sheet.Range["B5:H11"].RowHeight = 60;
                sheet.UsedRange.ColumnWidth = 15;

                //Set Legend
                sheet["K7"].BuiltInStyle = BuiltInStyles.Accent2_20;
                sheet["K8"].BuiltInStyle = BuiltInStyles.Accent4_20;

                sheet.Range["L7"].Text = "Holidays";
                sheet.Range["L8"].Text = "Today";
                sheet.Range["L7:L8"].CellStyle.VerticalAlignment = ExcelVAlign.VAlignCenter;
            }
            # endregion

            # region Styles for today
            foreach (IWorksheet cSheet in workbook.Worksheets)
            {
                if (cSheet.Name == monthArray[cMonth])
                {
                    //Apply styles for today
                    IRange tRange = cSheet.FindFirst(DateTime.Today.Day, ExcelFindType.Number);
                    tRange.BuiltInStyle = BuiltInStyles.Accent4_20;
                    tRange.CellStyle.Font.RGBColor = Color.Purple;

                    tRange.AddComment().Text = "Today";
                    tRange.Comment.Width = 100;
                    tRange.Comment.Height = 40;
                    cSheet.Activate();
                }
                else if (cSheet.Name == "Holidays")
                {
                    cSheet.Range["B3"].BuiltInStyle = BuiltInStyles.Accent2_20;
                    cSheet.Range["B3"].CellStyle.Font.FontName = "Calibri";
                    cSheet.Range["B3"].CellStyle.Font.Size = 11;
                    cSheet.Range["B3"].CellStyle.HorizontalAlignment = ExcelHAlign.HAlignCenter;
                }
            }

            # endregion

            # region Update Holidays

            //Highlight holidays
            for (int i = 8; i <= 18; i++)
            {
                int sheetIndex = workbook.Worksheets[12].Range["D" + i.ToString()].DateTime.Month;
                IRange holiday = workbook.Worksheets[sheetIndex - 1].FindFirst(workbook.Worksheets[12].Range["D" + i.ToString()].DateTime.Day, ExcelFindType.Number);
                holiday.AddComment().Text = workbook.Worksheets[12].Range["B" + i.ToString()].Text;
                holiday.Comment.Width = 100;
                holiday.Comment.Height = 40;
                holiday.BuiltInStyle = BuiltInStyles.Accent2_20;
                holiday.CellStyle.Font.RGBColor = Color.Red;
            }

            # endregion

            # endregion

            //Saving the workbook to disk.
            if (this.rdBtn2007.Checked)
                workbook.SaveAs("Sample.xlsx", Response, ExcelDownloadType.PromptDialog, ExcelHttpContentType.Excel2007);
            else if (this.rdBtn2010.Checked)
                workbook.SaveAs("Sample.xlsx", Response, ExcelDownloadType.PromptDialog, ExcelHttpContentType.Excel2010);
            else if (this.rdBtn2013.Checked)
                workbook.SaveAs("Sample.xlsx", Response, ExcelDownloadType.PromptDialog, ExcelHttpContentType.Excel2013);

            //Close the workbook.
            workbook.Close();
            excelEngine.Dispose();
        }
        # endregion

        # region Helpher Methods
        /// <summary>
        /// Data folder path is resolved from requested page physical path
        /// </summary>
        /// <param name="fileName"></param>
        /// <returns></returns>
        protected string ResolveApplicationDataPath(string fileName)
        {
            string dataPath = string.Format("{0}\\Common\\Data\\XlsIO\\", Request.PhysicalPath.ToLower().Split(new string[] { "\\web" }, StringSplitOptions.None));
            return string.Format("{0}\\{1}", dataPath, fileName);
        }
        # endregion
        protected void Button2_Click(object sender, EventArgs e)
        {
            //Step 1 : Instantiate the spreadsheet creation engine.
            ExcelEngine excelEngine = new ExcelEngine();
            //Step 2 : Instantiate the excel application object.
            IApplication application = excelEngine.Excel;
            //A new workbook is created.[Equivalent to creating a new workbook in MS Excel]
            //The new workbook will have 2 worksheets
            IWorkbook workbook = application.Workbooks.Open(ResolveApplicationDataPath("CalendarTemplate.xlsx"));
            workbook.Version = ExcelVersion.Excel2013;
            workbook.SaveAs("Template.xlsx", Response, ExcelDownloadType.PromptDialog);
        }
}
}